==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebFilteringExpressionsTreeDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata } from "./WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata";
import { WebFilteringExpressionsTreeDetailDescription } from "./WebFilteringExpressionsTreeDetailDescription";
/**
 * @hidden
 */
export let WebFilteringExpressionsTreeDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringExpressionsTreeDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringExpressionsTreeDetailDescriptionMetadata.a == null) {
                WebFilteringExpressionsTreeDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringExpressionsTreeDetailDescriptionMetadata.c(WebFilteringExpressionsTreeDetailDescriptionMetadata.a);
            }
            if (a.k(WebFilteringExpressionsTreeDetailDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebFilteringExpressionsTreeDetailDescriptionMetadata.a);
            WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringExpressionsTreeDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
            a.item("FilteringOperands", "Array:WebFilteringExpressionsTreeOrFilteringExpressionDescription:FilteringExpressionsTreeOrFilteringExpression");
            a.item("Operator", "ExportedType:string:FilteringLogic");
            a.item("Operator@names", "And;Or");
            a.item("FieldName", "String");
            a.item("TreeType", "(wc:Type)ExportedType:string:FilteringExpressionsTreeType");
            a.item("TreeType@names", "Regular;Advanced");
        }
        static d(a) {
            WebFilteringExpressionsTreeDetailDescriptionMetadata.b(a);
            a.ac("WebFilteringExpressionsTreeDetail", () => new WebFilteringExpressionsTreeDetailDescription());
            a.ab("WebFilteringExpressionsTreeDetail", WebFilteringExpressionsTreeDetailDescriptionMetadata.a);
        }
    }
    WebFilteringExpressionsTreeDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFilteringExpressionsTreeDetailDescriptionMetadata, 'WebFilteringExpressionsTreeDetailDescriptionMetadata');
    WebFilteringExpressionsTreeDetailDescriptionMetadata.a = null;
    return WebFilteringExpressionsTreeDetailDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebFilteringExpressionsTreeDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata } from "./WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata";
import { WebFilteringExpressionsTreeDetailDescription } from "./WebFilteringExpressionsTreeDetailDescription";
/**
 * @hidden
 */
export let WebFilteringExpressionsTreeDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringExpressionsTreeDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringExpressionsTreeDetailDescriptionMetadata.a == null) {
                WebFilteringExpressionsTreeDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringExpressionsTreeDetailDescriptionMetadata.c(WebFilteringExpressionsTreeDetailDescriptionMetadata.a);
            }
            if (a.k(WebFilteringExpressionsTreeDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebFilteringExpressionsTreeDetailDescriptionMetadata.a);
            WebFilteringExpressionsTreeOrFilteringExpressionDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringExpressionsTreeDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("FilteringOperands", "Array:WebFilteringExpressionsTreeOrFilteringExpressionDescription:FilteringExpressionsTreeOrFilteringExpression");
            a.item("TreeType", "(wc:Type)ExportedType:string:FilteringExpressionsTreeType");
            a.item("TreeType@names", "Regular;Advanced");
            a.item("Owner", "Unknown");
            a.item("Operator", "ExportedType:string:FilteringLogic");
            a.item("Operator@names", "And;Or");
            a.item("FieldName", "String");
            a.item("Entity", "String");
            a.item("ReturnFields", "Array:string");
        }
        static d(a) {
            WebFilteringExpressionsTreeDetailDescriptionMetadata.b(a);
            a.ae("WebFilteringExpressionsTreeDetail", () => new WebFilteringExpressionsTreeDetailDescription());
            a.ad("WebFilteringExpressionsTreeDetail", WebFilteringExpressionsTreeDetailDescriptionMetadata.a);
        }
    }
    WebFilteringExpressionsTreeDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFilteringExpressionsTreeDetailDescriptionMetadata, 'WebFilteringExpressionsTreeDetailDescriptionMetadata');
    WebFilteringExpressionsTreeDetailDescriptionMetadata.a = null;
    return WebFilteringExpressionsTreeDetailDescriptionMetadata;
})();
